@@ -1131,4 +1131,34 @@ pub static ATOMS: &'static [&'static str] = &[
     "z",
     "zoomAndPan",
     "zoomandpan",
+
+    "background-size",
+    "background-origin",
+    "background-clip",
+    "border-top-left-radius",
+    "border-top-right-radius",
+    "border-bottom-right-radius",
+    "border-bottom-left-radius",
+    "outline-color",
+    "outline-style",
+    "outline-width",
+    "overflow-wrap",
+    "list-style-image",
+    "list-style-position",
+    "list-style-type",
+    "column-count",
+    "column-width",
+    "overflow-x",
+    "overflow-y",
+    "transition-property",
+    "transition-duration",
+    "transition-timing-function",
+    "transition-delay",
+    "border-radius",
+    "outline",
+    "word-wrap",
+    "list-style",
+    "columns",
+    "transitions",
+
 ];
